pub struct BootMetadata {
pub zbi_type: Option<u32>,
pub zbi_extra: Option<u32>,
}Expand description
Device metadata to be passed from bootloader via a ZBI record.
Fields
zbi_type: Option<u32>zbi_extra: Option<u32>Trait Implementations
Sourceimpl Clone for BootMetadata
impl Clone for BootMetadata
Sourcefn clone(&self) -> BootMetadata
fn clone(&self) -> BootMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BootMetadata
Sourceimpl Debug for BootMetadata
impl Debug for BootMetadata
Sourceimpl Default for BootMetadata
impl Default for BootMetadata
Sourcefn default() -> BootMetadata
fn default() -> BootMetadata
Returns the “default value” for a type. Read more
Sourceimpl<___E> Encode<BootMetadata<'static>, ___E> for BootMetadatawhere
___E: Encoder + ?Sized,
impl<___E> Encode<BootMetadata<'static>, ___E> for BootMetadatawhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BootMetadata<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BootMetadata<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<BootMetadata<'static>, ___E> for &'a BootMetadatawhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<BootMetadata<'static>, ___E> for &'a BootMetadatawhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<BootMetadata<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<BootMetadata<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
impl Eq for BootMetadata
Sourceimpl<'de> FromWire<BootMetadata<'de>> for BootMetadata
impl<'de> FromWire<BootMetadata<'de>> for BootMetadata
Sourcefn from_wire(wire_: BootMetadata<'de>) -> Self
fn from_wire(wire_: BootMetadata<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<BootMetadata<'de>> for BootMetadata
impl<'de> FromWireRef<BootMetadata<'de>> for BootMetadata
Sourcefn from_wire_ref(wire: &BootMetadata<'de>) -> Self
fn from_wire_ref(wire: &BootMetadata<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for BootMetadata
impl Hash for BootMetadata
Sourceimpl Ord for BootMetadata
impl Ord for BootMetadata
Sourcefn cmp(&self, other: &BootMetadata) -> Ordering
fn cmp(&self, other: &BootMetadata) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BootMetadata
impl PartialEq for BootMetadata
Sourcefn eq(&self, other: &BootMetadata) -> bool
fn eq(&self, other: &BootMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BootMetadata
impl PartialOrd for BootMetadata
impl StructuralPartialEq for BootMetadata