pub struct PlatformBusGetBoardInfoResponse {
pub info: TemporaryBoardInfo,
}Fields
info: TemporaryBoardInfoTrait Implementations
Sourceimpl Clone for PlatformBusGetBoardInfoResponse
impl Clone for PlatformBusGetBoardInfoResponse
Sourcefn clone(&self) -> PlatformBusGetBoardInfoResponse
fn clone(&self) -> PlatformBusGetBoardInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<___E> Encode<PlatformBusGetBoardInfoResponse<'static>, ___E> for PlatformBusGetBoardInfoResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<PlatformBusGetBoardInfoResponse<'static>, ___E> for PlatformBusGetBoardInfoResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PlatformBusGetBoardInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PlatformBusGetBoardInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<PlatformBusGetBoardInfoResponse<'static>, ___E> for &'a PlatformBusGetBoardInfoResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<PlatformBusGetBoardInfoResponse<'static>, ___E> for &'a PlatformBusGetBoardInfoResponsewhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<PlatformBusGetBoardInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<PlatformBusGetBoardInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, PlatformBusGetBoardInfoResponse<'static>>, ___E> for PlatformBusGetBoardInfoResponsewhere
___E: Encoder + ?Sized,
PlatformBusGetBoardInfoResponse: Encode<PlatformBusGetBoardInfoResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, PlatformBusGetBoardInfoResponse<'static>>, ___E> for PlatformBusGetBoardInfoResponsewhere
___E: Encoder + ?Sized,
PlatformBusGetBoardInfoResponse: Encode<PlatformBusGetBoardInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PlatformBusGetBoardInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PlatformBusGetBoardInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, PlatformBusGetBoardInfoResponse<'static>>, ___E> for &'a PlatformBusGetBoardInfoResponsewhere
___E: Encoder + ?Sized,
&'a PlatformBusGetBoardInfoResponse: Encode<PlatformBusGetBoardInfoResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, PlatformBusGetBoardInfoResponse<'static>>, ___E> for &'a PlatformBusGetBoardInfoResponsewhere
___E: Encoder + ?Sized,
&'a PlatformBusGetBoardInfoResponse: Encode<PlatformBusGetBoardInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, PlatformBusGetBoardInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, PlatformBusGetBoardInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for PlatformBusGetBoardInfoResponse
Sourceimpl<'de> FromWire<PlatformBusGetBoardInfoResponse<'de>> for PlatformBusGetBoardInfoResponse
impl<'de> FromWire<PlatformBusGetBoardInfoResponse<'de>> for PlatformBusGetBoardInfoResponse
Sourcefn from_wire(wire: PlatformBusGetBoardInfoResponse<'de>) -> Self
fn from_wire(wire: PlatformBusGetBoardInfoResponse<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<PlatformBusGetBoardInfoResponse<'de>> for PlatformBusGetBoardInfoResponse
impl<'de> FromWireRef<PlatformBusGetBoardInfoResponse<'de>> for PlatformBusGetBoardInfoResponse
Sourcefn from_wire_ref(wire: &PlatformBusGetBoardInfoResponse<'de>) -> Self
fn from_wire_ref(wire: &PlatformBusGetBoardInfoResponse<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Ord for PlatformBusGetBoardInfoResponse
impl Ord for PlatformBusGetBoardInfoResponse
Sourcefn cmp(&self, other: &PlatformBusGetBoardInfoResponse) -> Ordering
fn cmp(&self, other: &PlatformBusGetBoardInfoResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PlatformBusGetBoardInfoResponse
impl PartialEq for PlatformBusGetBoardInfoResponse
Sourcefn eq(&self, other: &PlatformBusGetBoardInfoResponse) -> bool
fn eq(&self, other: &PlatformBusGetBoardInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PlatformBusGetBoardInfoResponse
impl PartialOrd for PlatformBusGetBoardInfoResponse
impl StructuralPartialEq for PlatformBusGetBoardInfoResponse