#[repr(C)]pub struct SysSuspendCallbackRequest {
pub enable_wake: bool,
pub suspend_reason: u8,
}Fields
enable_wake: boolsuspend_reason: u8Trait Implementations
Sourceimpl Clone for SysSuspendCallbackRequest
impl Clone for SysSuspendCallbackRequest
Sourcefn clone(&self) -> SysSuspendCallbackRequest
fn clone(&self) -> SysSuspendCallbackRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SysSuspendCallbackRequest
Sourceimpl Debug for SysSuspendCallbackRequest
impl Debug for SysSuspendCallbackRequest
Sourceimpl<___E> Encode<SysSuspendCallbackRequest, ___E> for SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SysSuspendCallbackRequest, ___E> for SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SysSuspendCallbackRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, SysSuspendCallbackRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SysSuspendCallbackRequest, ___E> for &'a SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SysSuspendCallbackRequest, ___E> for &'a SysSuspendCallbackRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, SysSuspendCallbackRequest>, ___E> for SysSuspendCallbackRequest
impl<___E> EncodeOption<Box<'static, SysSuspendCallbackRequest>, ___E> for SysSuspendCallbackRequest
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SysSuspendCallbackRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SysSuspendCallbackRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, SysSuspendCallbackRequest>, ___E> for &'a SysSuspendCallbackRequestwhere
___E: Encoder + ?Sized,
&'a SysSuspendCallbackRequest: Encode<SysSuspendCallbackRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, SysSuspendCallbackRequest>, ___E> for &'a SysSuspendCallbackRequestwhere
___E: Encoder + ?Sized,
&'a SysSuspendCallbackRequest: Encode<SysSuspendCallbackRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, SysSuspendCallbackRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, SysSuspendCallbackRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for SysSuspendCallbackRequest
Sourceimpl FromWire<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
impl FromWire<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackRequest, Self>
Sourcefn from_wire(wire: SysSuspendCallbackRequest) -> Self
fn from_wire(wire: SysSuspendCallbackRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
impl FromWireRef<SysSuspendCallbackRequest> for SysSuspendCallbackRequest
Sourcefn from_wire_ref(wire: &SysSuspendCallbackRequest) -> Self
fn from_wire_ref(wire: &SysSuspendCallbackRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for SysSuspendCallbackRequest
impl Hash for SysSuspendCallbackRequest
Sourceimpl Ord for SysSuspendCallbackRequest
impl Ord for SysSuspendCallbackRequest
Sourcefn cmp(&self, other: &SysSuspendCallbackRequest) -> Ordering
fn cmp(&self, other: &SysSuspendCallbackRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SysSuspendCallbackRequest
impl PartialEq for SysSuspendCallbackRequest
Sourcefn eq(&self, other: &SysSuspendCallbackRequest) -> bool
fn eq(&self, other: &SysSuspendCallbackRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SysSuspendCallbackRequest
impl PartialOrd for SysSuspendCallbackRequest
impl StructuralPartialEq for SysSuspendCallbackRequest