pub struct TemporaryBoardInfo {
pub vid: u32,
pub pid: u32,
pub board_name: String,
pub board_revision: u32,
}Expand description
This is originally from the Banjo fuchsia.hardware.platform.device library, but it is temporarily included here until that is migrated to FIDL.
Fields
vid: u32pid: u32board_name: Stringboard_revision: u32Trait Implementations
Sourceimpl Clone for TemporaryBoardInfo
impl Clone for TemporaryBoardInfo
Sourcefn clone(&self) -> TemporaryBoardInfo
fn clone(&self) -> TemporaryBoardInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TemporaryBoardInfo
impl Debug for TemporaryBoardInfo
Sourceimpl<___E> Encode<TemporaryBoardInfo<'static>, ___E> for TemporaryBoardInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<TemporaryBoardInfo<'static>, ___E> for TemporaryBoardInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TemporaryBoardInfo<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TemporaryBoardInfo<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> Encode<TemporaryBoardInfo<'static>, ___E> for &'a TemporaryBoardInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<TemporaryBoardInfo<'static>, ___E> for &'a TemporaryBoardInfowhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<TemporaryBoardInfo<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<TemporaryBoardInfo<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, TemporaryBoardInfo<'static>>, ___E> for TemporaryBoardInfo
impl<___E> EncodeOption<Box<'static, TemporaryBoardInfo<'static>>, ___E> for TemporaryBoardInfo
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TemporaryBoardInfo<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TemporaryBoardInfo<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, TemporaryBoardInfo<'static>>, ___E> for &'a TemporaryBoardInfo
impl<'a, ___E> EncodeOption<Box<'static, TemporaryBoardInfo<'static>>, ___E> for &'a TemporaryBoardInfo
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, TemporaryBoardInfo<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, TemporaryBoardInfo<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for TemporaryBoardInfo
Sourceimpl<'de> FromWire<TemporaryBoardInfo<'de>> for TemporaryBoardInfo
impl<'de> FromWire<TemporaryBoardInfo<'de>> for TemporaryBoardInfo
Sourcefn from_wire(wire: TemporaryBoardInfo<'de>) -> Self
fn from_wire(wire: TemporaryBoardInfo<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<TemporaryBoardInfo<'de>> for TemporaryBoardInfo
impl<'de> FromWireRef<TemporaryBoardInfo<'de>> for TemporaryBoardInfo
Sourcefn from_wire_ref(wire: &TemporaryBoardInfo<'de>) -> Self
fn from_wire_ref(wire: &TemporaryBoardInfo<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for TemporaryBoardInfo
impl Hash for TemporaryBoardInfo
Sourceimpl Ord for TemporaryBoardInfo
impl Ord for TemporaryBoardInfo
Sourcefn cmp(&self, other: &TemporaryBoardInfo) -> Ordering
fn cmp(&self, other: &TemporaryBoardInfo) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for TemporaryBoardInfo
impl PartialEq for TemporaryBoardInfo
Sourcefn eq(&self, other: &TemporaryBoardInfo) -> bool
fn eq(&self, other: &TemporaryBoardInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for TemporaryBoardInfo
impl PartialOrd for TemporaryBoardInfo
impl StructuralPartialEq for TemporaryBoardInfo