#[repr(C)]pub struct UserspaceIrq {
pub irq: u32,
pub controller_id: u32,
}Fields
irq: u32controller_id: u32Trait Implementations
Sourceimpl Clone for UserspaceIrq
impl Clone for UserspaceIrq
Sourcefn clone(&self) -> UserspaceIrq
fn clone(&self) -> UserspaceIrq
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for UserspaceIrq
Sourceimpl Debug for UserspaceIrq
impl Debug for UserspaceIrq
Sourceimpl<___E> Encode<UserspaceIrq, ___E> for UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<UserspaceIrq, ___E> for UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, UserspaceIrq>
const COPY_OPTIMIZATION: CopyOptimization<Self, UserspaceIrq>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserspaceIrq>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserspaceIrq>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<UserspaceIrq, ___E> for &'a UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<UserspaceIrq, ___E> for &'a UserspaceIrqwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<UserspaceIrq>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<UserspaceIrq>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, UserspaceIrq>, ___E> for UserspaceIrq
impl<___E> EncodeOption<Box<'static, UserspaceIrq>, ___E> for UserspaceIrq
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UserspaceIrq>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UserspaceIrq>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, UserspaceIrq>, ___E> for &'a UserspaceIrq
impl<'a, ___E> EncodeOption<Box<'static, UserspaceIrq>, ___E> for &'a UserspaceIrq
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, UserspaceIrq>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, UserspaceIrq>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for UserspaceIrq
Sourceimpl FromWire<UserspaceIrq> for UserspaceIrq
impl FromWire<UserspaceIrq> for UserspaceIrq
Sourceconst COPY_OPTIMIZATION: CopyOptimization<UserspaceIrq, Self>
const COPY_OPTIMIZATION: CopyOptimization<UserspaceIrq, Self>
Sourcefn from_wire(wire: UserspaceIrq) -> Self
fn from_wire(wire: UserspaceIrq) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<UserspaceIrq> for UserspaceIrq
impl FromWireRef<UserspaceIrq> for UserspaceIrq
Sourcefn from_wire_ref(wire: &UserspaceIrq) -> Self
fn from_wire_ref(wire: &UserspaceIrq) -> Self
Converts the given reference to this type.
Sourceimpl Hash for UserspaceIrq
impl Hash for UserspaceIrq
Sourceimpl Ord for UserspaceIrq
impl Ord for UserspaceIrq
Sourcefn cmp(&self, other: &UserspaceIrq) -> Ordering
fn cmp(&self, other: &UserspaceIrq) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for UserspaceIrq
impl PartialEq for UserspaceIrq
Sourcefn eq(&self, other: &UserspaceIrq) -> bool
fn eq(&self, other: &UserspaceIrq) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for UserspaceIrq
impl PartialOrd for UserspaceIrq
impl StructuralPartialEq for UserspaceIrq