#[repr(C)]pub struct SysSuspendCallbackResponse {
pub out_status: Status,
}Expand description
The wire type corresponding to SysSuspendCallbackResponse.
Fields
out_status: StatusTrait Implementations
Sourceimpl Clone for SysSuspendCallbackResponse
impl Clone for SysSuspendCallbackResponse
Sourcefn clone(&self) -> SysSuspendCallbackResponse
fn clone(&self) -> SysSuspendCallbackResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for SysSuspendCallbackResponse
impl Constrained for SysSuspendCallbackResponse
Sourceimpl Debug for SysSuspendCallbackResponse
impl Debug for SysSuspendCallbackResponse
Sourceimpl<___D> Decode<___D> for SysSuspendCallbackResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for SysSuspendCallbackResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<SysSuspendCallbackResponse, ___E> for SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<SysSuspendCallbackResponse, ___E> for SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, SysSuspendCallbackResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, SysSuspendCallbackResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<SysSuspendCallbackResponse, ___E> for &'a SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<SysSuspendCallbackResponse, ___E> for &'a SysSuspendCallbackResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<SysSuspendCallbackResponse, ___E> for SysSuspendCallbackResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
impl<___E, T0> Encode<SysSuspendCallbackResponse, ___E> for SysSuspendCallbackResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Status, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<SysSuspendCallbackResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<SysSuspendCallbackResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
impl FromWire<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<SysSuspendCallbackResponse, Self>
Sourcefn from_wire(wire: SysSuspendCallbackResponse) -> Self
fn from_wire(wire: SysSuspendCallbackResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
impl FromWireRef<SysSuspendCallbackResponse> for SysSuspendCallbackResponse
Sourcefn from_wire_ref(wire: &SysSuspendCallbackResponse) -> Self
fn from_wire_ref(wire: &SysSuspendCallbackResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for SysSuspendCallbackResponse
impl IntoNatural for SysSuspendCallbackResponse
Sourcetype Natural = SysSuspendCallbackResponse
type Natural = SysSuspendCallbackResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for SysSuspendCallbackResponse
impl Wire for SysSuspendCallbackResponse
Sourcetype Narrowed<'de> = SysSuspendCallbackResponse
type Narrowed<'de> = SysSuspendCallbackResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.